pub struct Cipher {Show 24 fields
pub id: Option<Uuid>,
pub organization_id: Option<Uuid>,
pub folder_id: Option<Uuid>,
pub collection_ids: Vec<Uuid>,
pub key: Option<EncString>,
pub name: EncString,
pub notes: Option<EncString>,
pub type: CipherType,
pub login: Option<Login>,
pub identity: Option<Identity>,
pub card: Option<Card>,
pub secure_note: Option<SecureNote>,
pub favorite: bool,
pub reprompt: CipherRepromptType,
pub organization_use_totp: bool,
pub edit: bool,
pub view_password: bool,
pub local_data: Option<LocalData>,
pub attachments: Option<Vec<Attachment>>,
pub fields: Option<Vec<Field>>,
pub password_history: Option<Vec<PasswordHistory>>,
pub creation_date: DateTime<Utc>,
pub deleted_date: Option<DateTime<Utc>>,
pub revision_date: DateTime<Utc>,
}Fields
id: Option<Uuid>organization_id: Option<Uuid>folder_id: Option<Uuid>collection_ids: Vec<Uuid>key: Option<EncString>More recent ciphers uses individual encryption keys to encrypt the other fields of the Cipher.
name: EncStringnotes: Option<EncString>type: CipherTypelogin: Option<Login>identity: Option<Identity>card: Option<Card>secure_note: Option<SecureNote>favorite: boolreprompt: CipherRepromptTypeorganization_use_totp: booledit: boolview_password: boollocal_data: Option<LocalData>attachments: Option<Vec<Attachment>>fields: Option<Vec<Field>>password_history: Option<Vec<PasswordHistory>>creation_date: DateTime<Utc>deleted_date: Option<DateTime<Utc>>revision_date: DateTime<Utc>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Cipher
impl<'de> Deserialize<'de> for Cipher
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Cipher
impl JsonSchema for Cipher
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl KeyDecryptable<SymmetricCryptoKey, CipherListView> for Cipher
impl KeyDecryptable<SymmetricCryptoKey, CipherListView> for Cipher
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<CipherListView, CryptoError>
Sourceimpl KeyDecryptable<SymmetricCryptoKey, CipherView> for Cipher
impl KeyDecryptable<SymmetricCryptoKey, CipherView> for Cipher
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<CipherView, CryptoError>
Sourceimpl KeyEncryptable<SymmetricCryptoKey, Cipher> for CipherView
impl KeyEncryptable<SymmetricCryptoKey, Cipher> for CipherView
fn encrypt_with_key( self, key: &SymmetricCryptoKey, ) -> Result<Cipher, CryptoError>
Sourceimpl LocateKey for Cipher
impl LocateKey for Cipher
fn locate_key<'a>( &self, enc: &'a dyn KeyContainer, _: &Option<Uuid>, ) -> Result<&'a SymmetricCryptoKey, CryptoError>
Sourceimpl TryFrom<CipherDetailsResponseModel> for Cipher
impl TryFrom<CipherDetailsResponseModel> for Cipher
Sourcetype Error = VaultParseError
type Error = VaultParseError
The type returned in the event of a conversion error.