pub struct CipherListView {Show 16 fields
pub id: Option<Uuid>,
pub organization_id: Option<Uuid>,
pub folder_id: Option<Uuid>,
pub collection_ids: Vec<Uuid>,
pub key: Option<EncString>,
pub name: String,
pub sub_title: String,
pub type: CipherListViewType,
pub favorite: bool,
pub reprompt: CipherRepromptType,
pub edit: bool,
pub view_password: bool,
pub attachments: u32,
pub creation_date: DateTime<Utc>,
pub deleted_date: Option<DateTime<Utc>>,
pub revision_date: DateTime<Utc>,
}Fields
id: Option<Uuid>organization_id: Option<Uuid>folder_id: Option<Uuid>collection_ids: Vec<Uuid>key: Option<EncString>Temporary, required to support calculating TOTP from CipherListView.
name: Stringsub_title: Stringtype: CipherListViewTypefavorite: boolreprompt: CipherRepromptTypeedit: boolview_password: boolattachments: u32The number of attachments
creation_date: DateTime<Utc>deleted_date: Option<DateTime<Utc>>revision_date: DateTime<Utc>Trait Implementations
Sourceimpl Debug for CipherListView
impl Debug for CipherListView
Sourceimpl<'de> Deserialize<'de> for CipherListView
impl<'de> Deserialize<'de> for CipherListView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CipherListView
impl JsonSchema for CipherListView
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl KeyDecryptable<SymmetricCryptoKey, CipherListView> for Cipher
impl KeyDecryptable<SymmetricCryptoKey, CipherListView> for Cipher
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<CipherListView, CryptoError>
Sourceimpl LocateKey for CipherListView
impl LocateKey for CipherListView
fn locate_key<'a>( &self, enc: &'a dyn KeyContainer, _: &Option<Uuid>, ) -> Result<&'a SymmetricCryptoKey, CryptoError>
Sourceimpl PartialEq for CipherListView
impl PartialEq for CipherListView
Sourceimpl Serialize for CipherListView
impl Serialize for CipherListView
impl StructuralPartialEq for CipherListView