pub struct Collection {
pub id: Option<Uuid>,
pub organization_id: Uuid,
pub name: EncString,
pub external_id: Option<String>,
pub hide_passwords: bool,
pub read_only: bool,
}Fields
id: Option<Uuid>organization_id: Uuidname: EncStringexternal_id: Option<String>hide_passwords: boolread_only: boolTrait Implementations
Sourceimpl Debug for Collection
impl Debug for Collection
Sourceimpl<'de> Deserialize<'de> for Collection
impl<'de> Deserialize<'de> for Collection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Collection
impl JsonSchema for Collection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl KeyDecryptable<SymmetricCryptoKey, CollectionView> for Collection
impl KeyDecryptable<SymmetricCryptoKey, CollectionView> for Collection
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<CollectionView, CryptoError>
Sourceimpl LocateKey for Collection
impl LocateKey for Collection
fn locate_key<'a>( &self, enc: &'a dyn KeyContainer, _: &Option<Uuid>, ) -> Result<&'a SymmetricCryptoKey, CryptoError>
Sourceimpl Serialize for Collection
impl Serialize for Collection
Sourceimpl TryFrom<CollectionDetailsResponseModel> for Collection
impl TryFrom<CollectionDetailsResponseModel> for Collection
Sourcetype Error = VaultParseError
type Error = VaultParseError
The type returned in the event of a conversion error.