pub struct FolderView {
pub id: Option<Uuid>,
pub name: String,
pub revision_date: DateTime<Utc>,
}Fields
id: Option<Uuid>name: Stringrevision_date: DateTime<Utc>Trait Implementations
Sourceimpl Debug for FolderView
impl Debug for FolderView
Sourceimpl<'de> Deserialize<'de> for FolderView
impl<'de> Deserialize<'de> for FolderView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FolderView
impl JsonSchema for FolderView
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl KeyDecryptable<SymmetricCryptoKey, FolderView> for Folder
impl KeyDecryptable<SymmetricCryptoKey, FolderView> for Folder
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<FolderView, CryptoError>
Sourceimpl KeyEncryptable<SymmetricCryptoKey, Folder> for FolderView
impl KeyEncryptable<SymmetricCryptoKey, Folder> for FolderView
fn encrypt_with_key( self, key: &SymmetricCryptoKey, ) -> Result<Folder, CryptoError>