pub struct PasswordHistory { /* private fields */ }Trait Implementations
Sourceimpl Clone for PasswordHistory
impl Clone for PasswordHistory
Sourcefn clone(&self) -> PasswordHistory
fn clone(&self) -> PasswordHistory
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PasswordHistory
impl Debug for PasswordHistory
Sourceimpl<'de> Deserialize<'de> for PasswordHistory
impl<'de> Deserialize<'de> for PasswordHistory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PasswordHistory
impl JsonSchema for PasswordHistory
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl KeyDecryptable<SymmetricCryptoKey, PasswordHistoryView> for PasswordHistory
impl KeyDecryptable<SymmetricCryptoKey, PasswordHistoryView> for PasswordHistory
fn decrypt_with_key( &self, key: &SymmetricCryptoKey, ) -> Result<PasswordHistoryView, CryptoError>
Sourceimpl KeyEncryptable<SymmetricCryptoKey, PasswordHistory> for PasswordHistoryView
impl KeyEncryptable<SymmetricCryptoKey, PasswordHistory> for PasswordHistoryView
fn encrypt_with_key( self, key: &SymmetricCryptoKey, ) -> Result<PasswordHistory, CryptoError>
Sourceimpl Serialize for PasswordHistory
impl Serialize for PasswordHistory
Sourceimpl TryFrom<CipherPasswordHistoryModel> for PasswordHistory
impl TryFrom<CipherPasswordHistoryModel> for PasswordHistory
Sourcetype Error = VaultParseError
type Error = VaultParseError
The type returned in the event of a conversion error.